@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -38,39 +33,41 @@ catch (Exception $e) {
 
 // VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
 $fields = [
-	'default_lang' =>		[T_ZBX_STR, O_OPT, null,	null,				null],
-	'type' =>				[T_ZBX_STR, O_OPT, null,	IN('"'.ZBX_DB_MYSQL.'","'.ZBX_DB_POSTGRESQL.'","'.ZBX_DB_ORACLE.'"'), null],
-	'server' =>				[T_ZBX_STR, O_OPT, null,	null,				null],
-	'port' =>				[T_ZBX_INT, O_OPT, null,	BETWEEN(0, 65535),	null, _('Database port')],
-	'database' =>			[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,			'(isset({type}) && {type} !== "'.ZBX_DB_ORACLE.'")', _('Database name')],
-	'user' =>				[T_ZBX_STR, O_OPT, null,	null,				null],
-	'password' =>			[T_ZBX_STR, O_OPT, null,	null, 				null],
-	'schema' =>				[T_ZBX_STR, O_OPT, null,	null, 				null],
-	'tls_encryption' =>		[T_ZBX_INT, O_OPT, null,	IN([0,1]),			null],
-	'verify_certificate' =>	[T_ZBX_INT, O_OPT, null,	IN([0,1]),			null],
-	'verify_host' =>		[T_ZBX_INT, O_OPT, null,	IN([0,1]),			null],
-	'key_file' =>			[T_ZBX_STR, O_OPT, null,	null, 				null],
-	'cert_file' =>			[T_ZBX_STR, O_OPT, null,	null, 				null],
-	'ca_file' =>			[T_ZBX_STR, O_OPT, null,	null, 				null],
-	'cipher_list' =>		[T_ZBX_STR, O_OPT, null,	null, 				null],
-	'creds_storage' =>		[T_ZBX_INT, O_OPT, null,	IN([DB_STORE_CREDS_CONFIG, DB_STORE_CREDS_VAULT_HASHICORP, DB_STORE_CREDS_VAULT_CYBERARK]), null],
-	'vault_url' =>			[T_ZBX_STR, O_OPT, null,	null,				null],
-	'vault_db_path' =>		[T_ZBX_STR, O_OPT, null,	null,				null],
-	'vault_query_string' =>	[T_ZBX_STR, O_OPT, null,	null,				null],
-	'vault_token' =>		[T_ZBX_STR, O_OPT, null,	null,				null],
-	'vault_certificates' =>	[T_ZBX_INT, O_OPT, null,	IN([0,1]),			null],
-	'vault_cert_file' =>	[T_ZBX_STR, O_OPT, null,	null,				null],
-	'vault_key_file' =>		[T_ZBX_STR, O_OPT, null,	null,				null],
-	'zbx_server_name' =>	[T_ZBX_STR, O_OPT, null,	null,				null],
-	'default_timezone' =>	[T_ZBX_STR, O_OPT, null,	null,				null],
-	'default_theme' =>		[T_ZBX_STR, O_OPT, null,	null,				null],
+	'default_lang' =>			[T_ZBX_STR, O_OPT, null,	null,				null],
+	'type' =>					[T_ZBX_STR, O_OPT, null,	IN('"'.ZBX_DB_MYSQL.'","'.ZBX_DB_POSTGRESQL.'"'), null],
+	'server' =>					[T_ZBX_STR, O_OPT, null,	null,				null],
+	'port' =>					[T_ZBX_INT, O_OPT, null,	BETWEEN(0, 65535),	null, _('Database port')],
+	'database' =>				[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,			null, _('Database name')],
+	'user' =>					[T_ZBX_STR, O_OPT, null,	null,				null],
+	'password' =>				[T_ZBX_STR, O_OPT, null,	null, 				null],
+	'schema' =>					[T_ZBX_STR, O_OPT, null,	null, 				null],
+	'tls_encryption' =>			[T_ZBX_INT, O_OPT, null,	IN([0,1]),			null],
+	'verify_certificate' =>		[T_ZBX_INT, O_OPT, null,	IN([0,1]),			null],
+	'verify_host' =>			[T_ZBX_INT, O_OPT, null,	IN([0,1]),			null],
+	'key_file' =>				[T_ZBX_STR, O_OPT, null,	null, 				null],
+	'cert_file' =>				[T_ZBX_STR, O_OPT, null,	null, 				null],
+	'ca_file' =>				[T_ZBX_STR, O_OPT, null,	null, 				null],
+	'cipher_list' =>			[T_ZBX_STR, O_OPT, null,	null, 				null],
+	'creds_storage' =>			[T_ZBX_INT, O_OPT, null,	IN([DB_STORE_CREDS_CONFIG, DB_STORE_CREDS_VAULT_HASHICORP, DB_STORE_CREDS_VAULT_CYBERARK]), null],
+	'vault_url' =>				[T_ZBX_STR, O_OPT, null,	null,				null],
+	'vault_prefix_hashicorp' =>	[T_ZBX_STR, O_OPT, null,	null,				null],
+	'vault_prefix_cyberark' =>	[T_ZBX_STR, O_OPT, null,	null,				null],
+	'vault_db_path' =>			[T_ZBX_STR, O_OPT, null,	null,				null],
+	'vault_query_string' =>		[T_ZBX_STR, O_OPT, null,	null,				null],
+	'vault_token' =>			[T_ZBX_STR, O_OPT, null,	null,				null],
+	'vault_certificates' =>		[T_ZBX_INT, O_OPT, null,	IN([0,1]),			null],
+	'vault_cert_file' =>		[T_ZBX_STR, O_OPT, null,	null,				null],
+	'vault_key_file' =>			[T_ZBX_STR, O_OPT, null,	null,				null],
+	'zbx_server_name' =>		[T_ZBX_STR, O_OPT, null,	null,				null],
+	'default_timezone' =>		[T_ZBX_STR, O_OPT, null,	null,				null],
+	'default_theme' =>			[T_ZBX_STR, O_OPT, null,	null,				null],
 	// actions
-	'save_config' =>		[T_ZBX_STR, O_OPT, P_SYS,	null,				null],
-	'retry' =>				[T_ZBX_STR, O_OPT, P_SYS,	null,				null],
-	'cancel' =>				[T_ZBX_STR, O_OPT, P_SYS,	null,				null],
-	'finish' =>				[T_ZBX_STR, O_OPT, P_SYS,	null,				null],
-	'next' =>				[T_ZBX_STR, O_OPT, P_SYS|P_ONLY_ARRAY,	null,	null],
-	'back' =>				[T_ZBX_STR, O_OPT, P_SYS|P_ONLY_ARRAY,	null,	null]
+	'save_config' =>			[T_ZBX_STR, O_OPT, P_SYS,	null,				null],
+	'retry' =>					[T_ZBX_STR, O_OPT, P_SYS,	null,				null],
+	'cancel' =>					[T_ZBX_STR, O_OPT, P_SYS,	null,				null],
+	'finish' =>					[T_ZBX_STR, O_OPT, P_SYS,	null,				null],
+	'next' =>					[T_ZBX_STR, O_OPT, P_SYS|P_ONLY_ARRAY,	null,	null],
+	'back' =>					[T_ZBX_STR, O_OPT, P_SYS|P_ONLY_ARRAY,	null,	null]
 ];
 
 $check_fields_result = check_fields($fields, false);
@@ -157,11 +154,14 @@ DBclose();
 /*
  * Setup wizard
  */
-$setup_wizard = (new CSetupWizard())->cleanItems();
+$setup_wizard = new CSetupWizard();
 
 // page title
-(new CPageHeader(_('Installation'), substr($default_lang, 0, strpos($default_lang, '_'))))
-	->addCssFile('assets/styles/'.CHtml::encode($default_theme).'.css')
+$page_header = (new CHtmlPageHeader(_('Installation'), substr($default_lang, 0, strpos($default_lang, '_'))));
+
+$page_header
+	->setTheme($default_theme)
+	->addCssFile('assets/styles/'.$page_header->getTheme().'.css')
 	->addJsFile((new CUrl('js/browsers.js'))->getUrl())
 	->addJsFile((new CUrl('jsLoader.php'))
 		->setArgument('ver', ZABBIX_VERSION)
@@ -174,12 +174,12 @@ $setup_wizard = (new CSetupWizard())->cleanItems();
 		->setArgument('files', ['setup.js'])
 		->getUrl()
 	)
-	->display();
+	->show();
 
 /*
  * Displaying
  */
-$link = (new CLink('GPL v2', 'https://www.zabbix.com/license'))
+$link = (new CLink('AGPLv3', 'https://www.zabbix.com/license'))
 	->setTarget('_blank')
 	->addClass(ZBX_STYLE_GREY)
 	->addClass(ZBX_STYLE_LINK_ALT);
